#[non_exhaustive]pub struct Closed {
pub reason: ConnectionError,
pub stats: ConnectionStats,
pub path_stats: Vec<(PathId, PathStats)>,
}Expand description
State of a Connection at the moment it was closed.
Returned by the OnClosed future from Connection::on_closed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reason: ConnectionErrorThe reason the connection was closed.
stats: ConnectionStatsAggregate connection statistics at the moment of close.
path_stats: Vec<(PathId, PathStats)>Per-path statistics for every path the connection knew about at close time.
This includes paths that haven’t been discarded at close time, plus any
already-discarded paths whose final stats had been retained because a Path
or WeakPathHandle handle was kept alive.