pub struct FourTuple { /* private fields */ }Expand description
Identifies a network path by the combination of remote and local addresses
Including the local ensures good behavior when the host has multiple IP addresses on the same subnet and zero-length connection IDs are in use or when multipath is enabled and multiple paths exist with the same remote, but different local IP interfaces.
FourTuple implements From<SocketAddr>, which expands to Self::from_remote.
Implementations
Sourceimpl FourTuple
impl FourTuple
Sourcepub fn from_remote(remote: SocketAddr) -> FourTuple
pub fn from_remote(remote: SocketAddr) -> FourTuple
Creates a new FourTuple without a known local address.
Sourcepub fn remote(&self) -> SocketAddr
pub fn remote(&self) -> SocketAddr
Returns the remote address of the network path.