pub struct WeakPathHandle { /* private fields */ }Expand description
Weak handle for a Path that does not keep the connection alive.
As long as a WeakPathHandle for a path exists, that path’s final stats will not be dropped even if
the path was abandoned.
The WeakPathHandle can be upgraded to a Path as long as its Connection has not been dropped.
Implementations